% Reduction 22-May-2020 

% read spreadsheets from gso, nbc, nbnerr labs

% create & save single new table with columns
%   station - 2-letter string code (as cell)
%   Date - as Matlab datetime
%   Time - as fraction of 24 hrs
%   dnest = datenum EST
%   val1, val2, val3 - "vals" = lab reps and dups (nans if less than 3)
%         all are conc of CHL A (not total chl) in ug/L from lab analysis
%   mean - mean of vals
%   stdev - stdev of vals
%   minmaxdif - max minus min
%   n - number of non-nan vals

% print to screen some basic statitics

% NOTES
% nbc - PD and BR 
%       exclude middle, deep sensors
%       move "duplicates" to be one of the (up to three) "vals"
%       only a few early dates have all three "vals"
%       most dates have only one "val"
%       adjust times to be EST (from EDT)

% gso - all other stations
%       exclude cases where comment or othernotes columns are not empty
%       exclude if mean from indiv vals doesn't equal mean in 1st sheet

% tw - average times of vals on same day, usually differ by ~minutes

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

%% GSO FILE

% FIRST SHEET: MEANS (dates get used; not mean values)
fprintf('\n\nREADING FROM MEAN SHEET\n\n')
fprintf('This WARNING is benign:');
tm = readtable(infil.gso,'sheet','CHL Sample Averages');
fprintf('initial table (raw from spreadsheet) %d rows\n',length(tm.Date));
% remove empty rows
tm = tm(~isnat(tm.Date),:);
fprintf('%d rows after remove blankspace rows\n',length(tm.Date));
% remove rows with non-empty Comments column
tm = tm(cellfun(@isempty,tm.Comments),:);
fprintf('%d rows after remove rows with comments\n',length(tm.Date));
% remove rows with non-empty otherNotes column
tm = tm(cellfun(@isempty,tm.otherNotes),:);
fprintf('%d rows after remove rows with other notes\n',length(tm.Date));
% remove rows with no value
tm = tm(~isnan(tm.mean),:);
fprintf('%d rows after remove rows with NaN mean val\n',length(tm.Date));
% remove UB, NB, and GD stations
tm = tm(~ismember(tm.Station,{'UB';'NB';'GD'}),:);
fprintf('%d rows after remove UB/NB/GD stations\n',length(tm.Date));
% remove comments and othernotes columns
tm.Comments = [];
tm.otherNotes = [];
% add columns to tm table for n, stdev, and mymean
%       to be calculated below using REPS sheet values (after reading them)
tm.n = nan*ones(height(tm),1);
tm.stdev = nan*ones(height(tm),1);
tm.mymean = nan*ones(height(tm),1);
tm.val1 = nan*ones(height(tm),1);
tm.val2 = nan*ones(height(tm),1);
tm.val3 = nan*ones(height(tm),1);

% READ SECOND SHEET: REPS
fprintf('\n\nREADING FROM REPS SHEET\n\n')
tr = readtable(infil.gso,'sheet','CHL Sample Data','Range','A1:D6155');
fprintf('initial table (raw from spreadsheet) %d rows\n',length(tr.Date));
% remove empty rows
tr = tr(~isnat(tr.Date),:);
fprintf('%d rows after remove blankspace rows\n',length(tr.Date));
% remove rows with no value
tr = tr(~isnan(tr.Chla),:);
fprintf('%d rows after remove rows with NaN mean val\n',length(tr.Date));

% loop through each date/time/station in tm, use matches in tr to compute
%           n, stdev, and mean, then put them in to tm
for irow = 1:height(tm)
    [~,ind] = ismember(tr.Station,tm.Station(irow));
    ind = find(ind & tr.Date==tm.Date(irow) & tr.Time==tm.Time(irow));
    if sum(isnan(tr.Chla(ind)))<2
        tm.stdev(irow) = std(tr.Chla(ind));
    else
        tm.stdev(irow) = nan;
    end
    tm.mymean(irow) = nanmean(tr.Chla(ind));
    num = min(length(ind),3);
    tm.n(irow) = num;
    for i = 1:num
        eval(sprintf('tm.val%d(irow) = tr.Chla(ind(i));',i));
    end
    clear ind i num;
end
clear irow tr;

% remove any for which mymean are not equal to mean to within 0.1
ind = find(abs(tm.mean-tm.mymean)<0.1);
tm = tm(ind,:);
clear ind;

% reorder columns, drop original mean (in favor of mean computed here)
tm = [tm(:,2) tm(:,1) tm(:,3) tm(:,8:10) tm(:,7) tm(:,6) tm(:,5)];
% rename mean
tm.Properties.VariableNames([7]) = {'mean'};

%% NBC FILE (PD & BR)
fprintf('\n\nREADING FROM NBC SHEET\n\n')
fprintf('This WARNING is benign:');
tn = readtable(infil.nbc);
% keep only columns of interest
tn = tn(:,[1 2 4 17 18]);
% remove middle sensor results
tn = tn(~ismember(tn.Station,'Bullock Reach Buoy Middle'),:);
% rename columns
tn.Properties.VariableNames = {'Date';'Time';'Station';'val1';'val2'};
% move duplicates to new column val3
tn.val3 = nan*ones(height(tn),1);
dups = [];
for irow = 1:height(tn)
    if ~isempty(strfind(tn.Station{irow},'(Duplicate)'))
        ind = find(tn.Date==tn.Date(irow) & tn.Time==tn.Time(irow));
        ind = ind(find(ind~=irow));
        tn.val3(ind) = tn.val1(irow);
        dups = [dups irow];
        clear ind;
    end
end
tn(dups,:) = [];
clear dups;
% rename stations
for irow = 1:height(tn)
    if isequal(tn.Station{irow}(1:25),'Phillipsdale Landing Surf')
        tn.Station(irow) = {'PD'};
    elseif isequal(tn.Station{irow}(1:25),'Bullock Reach Buoy Surfac')
        tn.Station(irow) = {'BR'};
    end
end
clear irow;
% keep only surface 
tn = tn(ismember(tn.Station,{'BR';'PD'}),:);
% reorder columns
tn = [tn(:,3) tn(:,[1 2]) tn(:,[4:6])];
% compute remaining columns
dat = tn{:,[4:6]}';
tn.mean = nanmean(dat)';
tn.n = sum(~isnan(dat))';
tn.stdev = nanstd(dat)';
tn.stdev(tn.n==1) = nan;
clear dat;
% convert times to EST (from EDT)
tn.Time(isdst(datetime(tn.Date,'TimeZone','America/New_York'))) = ...
    tn.Time(isdst(datetime(tn.Date,'TimeZone','America/New_York')))-1/24;
% merge with gso data
all = [tm; tn;];
clear tm tn;

%% TW file
fprintf('\n\nREADING FROM TW SHEET\n\n')
tt = readtable(infil.tw);
% keep only columns of interest
tt = tt(:,[3 4 5 6]);
tt.Properties.VariableNames = {'DateTime';'valnum';'val1';'qual'};
% keep only good qual, drop qual column
tt = tt(ismember(tt.qual,{'0','<0>','<4>','<5> (CSM)','<5> [SRD] (CSM)'}),:);
tt = tt(:,{'DateTime';'valnum';'val1';});
% add columns for val2 and val3
tt.val2 = nan*ones(height(tt),1);
tt.val3 = nan*ones(height(tt),1);
% create Date and Time columns from Datetime
tt.Date = datetime(year(tt.DateTime),month(tt.DateTime),day(tt.DateTime));
tt.rawTime = (hour(tt.DateTime) + (minute(tt.DateTime)/60))/24;
tt.Time = nan*ones(height(tt),1);
% average the times from individual dates
unqdt = unique(tt.Date);
for i = 1:length(unqdt)
    ind = tt.Date==unqdt(i);
    tt.Time(ind) = nanmean(tt.rawTime(ind));
    clear ind;
end
clear i unqdt;
% remove rawTime and Datetime columns
tt = tt(:,[6 8 2 3 4 5]);
unqdt = unique(tt.Date);
for i = 1:length(unqdt)
    ind = find(tt.Date==unqdt(i));
    if length(ind)>1
        ind1 = find(tt.valnum(ind)==1);
        ind2 = find(tt.valnum(ind)==2);
        dat = tt.val1(ind);
        tt.val2(ind(ind1)) = dat(ind2);
        clear ind1 ind2 dat;
    end
    clear ind;
end
clear i unqdt;
tt = tt(tt.valnum==1,:);
% add Station column, remove valnum column, reorder
tt.Station = cellstr(repmat({'TW'},1,height(tt))');
tt = tt(:,[7 1 2 4 5 6]);
% add and compute mean stdev n columns
dat = tt{:,[4:6]}';
tt.mean = nanmean(dat)';
tt.n = sum(~isnan(dat))';
tt.stdev = nanstd(dat)';
tt.stdev(tt.n==1) = nan;
clear dat;
% merge with gso & nbc data; sort
all = [all; tt;];
clear tt;
all = sortrows(all,[1 2 3]);

% add column for dnest (computed from Date and Time columns)
all.dnest = datenum(year(all.Date),month(all.Date),day(all.Date),...
    floor(all.Time*24),(all.Time*24 - floor(all.Time*24))*60,0);
all = all(:,[1 2 3 10 4 5 6 7 8 9]);

% add minmaxdif
dat = all{:,[5:7]}';
all.minmaxdif = (nanmax(dat) - nanmin(dat))';
all.minmaxdif(all.n<2) = nan;

% rename and save
grabs = all;
save dat/grabs grabs;

% compute and echo basic stats & put in table 
stns = unique(all.Station);
t = array2table(nan(0,16),'VariableNames',...
    {'Stn','DateSt','DateFn','nTot','n3val','n2val','n1val',...
    'min(avg)','avg(avg)','max(avg)',...
    'min(std)','avg(std)','max(std)',...
    'min(dif)','avg(dif)','max(dif)'});
t.Stn = cell(0,16);
t.DateSt = datetime(zeros(0,3));
t.DateFn = datetime(zeros(0,3));
for istn = 1:length(stns)
    fprintf('\n\nStation %s\n',stns{istn});
    dat = all(ismember(all.Station,stns(istn)),:);
    t.Stn(istn) = stns(istn);
    t.DateSt(istn) = dat.Date(1);
    t.DateFn(istn) = dat.Date(end);
    t.nTot(istn) = length(dat.Date);
    t.n3val(istn) = length(find(dat.n==3));
    t.n2val(istn) = length(find(dat.n==2));
    t.n1val(istn) = length(find(dat.n==1));
    t{istn,8} = nanmin(dat.mean);
    t{istn,9} = nanmean(dat.mean);
    t{istn,10} = nanmax(dat.mean);
    t{istn,11} = nanmin(dat.stdev);
    t{istn,12} = nanmean(dat.stdev);
    t{istn,13} = nanmax(dat.stdev);
    t{istn,14} = nanmin(dat.minmaxdif);
    t{istn,15} = nanmean(dat.minmaxdif);
    t{istn,16} = nanmax(dat.minmaxdif);
    fprintf('   dates: first/last/number/unique number: %s, %s, %d, %d\n',...
      dat.Date(1),dat.Date(end),length(dat.Date),length(unique(dat.Date)));
    fprintf('   number dates with 3/2/1 vals: %d/%d/%d\n',...
    length(find(dat.n==3)),length(find(dat.n==2)),length(find(dat.n==1)));
    fprintf('   means: min,mean,max %.1f, %.1f, %.1f\n',...
        nanmin(dat.mean),nanmean(dat.mean),nanmax(dat.mean));
    fprintf('   stdevs: min,mean,max %.1f, %.1f, %.1f\n',...
        nanmin(dat.stdev),nanmean(dat.stdev),nanmax(dat.stdev));
    fprintf('   minmaxdifs: min,mean,max %.1f, %.1f, %.1f\n',...
        nanmin(dat.minmaxdif),nanmean(dat.minmaxdif),nanmax(dat.minmaxdif));
    clear dat;
end
clear stns istn;
t = rows2vars(t,'VariableNamesSource','Stn');
t.Properties.VariableNames(1) = {' '};
t = t(:,[1 8 2 3 7 4 11 6 10 9 5 12]);    
% to get ~nicely formatted table for cut-paste to report:
fig = uifigure;
uit = uitable(fig,'Data',t);
    
% end of module
diary off;