% rawplotgrabs 23-May-2020 

% repeat what rawplot does 
% but superpose the grab sample data
%       (and adjust the details of the graphics)

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

% load grabs data
load(grabfil);

% get and group filenames
stn = {'BR'; 'CP'; 'NP'; 'MV'; 'QP'; 'PP'; 'TW'; 'GB'; 'SR'; 'MH'; 'PD';};
dirdat = dir([indir '*.mat']);
for i = 1:length(stn)
    ctr = 0;
    for j = 1:length(dirdat)
        if isequal(dirdat(j).name(1:2),stn{i})
            ctr = ctr+1;
            allfil{i}{ctr} = dirdat(j).name;
        end
    end
end

% figure out max number of years
nyr = 0; 
for i = 1:length(stn)
    if length(allfil{i}) > nyr
        nyr = length(allfil{i});
    end
end

ht = (15/nyr)*0.0265;


% do chl plots
fprintf('chl\n');
for i = 1:length(stn)
    fprintf('   working on stn %d of %d\n',i,length(stn));
    grb = grabs(ismember(grabs.Station,stn(i)),:);
    figport('on');
    for j = 1:length(allfil{i})
        dat = load([indir allfil{i}{j}]);
        iyr = str2num(allfil{i}{j}(5:6));
        fprintf('      year %d\n',iyr);
        subplot(nyr,1,iyr);
        pos = get(gca,'position');
        set(gca,'position',[pos(1) pos(2)-(ht/2) pos(3) 2*ht]);
        plot(dat.qh.dnest,dat.qh.sh.chl,'.');
        hold;
        whr = find(dat.qh.sh.chl<0);
        if length(whr)
            plot(dat.qh.dnest(whr),dat.qh.sh.chl(whr),'c.');
        end
        whr = find(dat.qh.sh.chl>max(ylimchl));
        if length(whr)
            plot(dat.qh.dnest(whr),(max(ylimchl)-0.01)*ones(size(whr)),'g.');
            fprintf('OVER YLIMCHL\n');
            for k = 1:length(whr)
                fprintf('%s %f\n',datestr(dat.qh.dnest(whr(k))),...
                    dat.qh.sh.chl(whr(k)));
            end
        end
        set(gca,'xlim',[datenum(2000+iyr,monst,dayst) ...
            datenum(2000+iyr,monfn,dayfn+0.25/24)]);
        set(gca,'ylim',ylimchl);
        ylabel(sprintf('%d',2000+iyr));
        grid on;
        datetick('keeplimits');
        if j==1
            title([dat.locn.name '; near-surface chlorophyll '...
                'concentration [ug l^{-1}], 15-minute resolution']);
        end
        if j ~= length(allfil{i})
            set(gca,'xticklabel',[]);
        end
        dnst = datenum(2000+iyr,monst,dayst);
        dnfn = datenum(2000+iyr,monfn,dayfn);
        whr = dat.qh.dnest>=dnst & dat.qh.dnest<=dnfn;
        nactual = length(find(dat.qh.sh.chl(whr)>=0 & ...
                        ~isnan(dat.qh.sh.chl(whr))));
        npossible = length(dnst:(15/1440):dnfn);
        pct = 100*nactual/npossible;
        text(min(get(gca,'xlim'))+0.75*diff(get(gca,'xlim')),...
            min(ylim)+0.8*diff(ylim),sprintf('%d/%d = %.1f%%',...
            nactual,npossible,pct));
        clear pos dat iyr whr nactual dnst dnfn;
        % add grab points in red
        ind = find(grb.dnest>=min(get(gca,'xlim')) & ...
                    grb.dnest<=max(get(gca,'xlim')) );
        if length(ind) > 0
            plot(grb.dnest(ind),grb.val1(ind),'r.');
            plot(grb.dnest(ind),grb.val2(ind),'r.');
            plot(grb.dnest(ind),grb.val3(ind),'r.');
        end
        clear ind;
    end
    eval(sprintf('print -dpng plt/chl%d%s;',i,stn{i}));
    delete(gcf);
    clear grb;
end

% end of module
diary off;